@@ -2,6 +2,7 @@ module Main
 ( main
 ) where
 
+import qualified Accum
 import qualified Catch
 import qualified Choose
 import qualified Cull
@@ -24,7 +25,8 @@ import qualified Writer
 
 main :: IO ()
 main = defaultMain $ map checkTestTree
-  [ Catch.tests
+  [ Accum.tests
+  , Catch.tests
   , Choose.tests
   , Cull.tests
   , Cut.tests
